@@ -66,7 +66,10 @@ class TestCase(object):
     def teardown_method(self, method):
         QueryPool.queries = []
         versioning_manager.reset()
+        versioning_manager.uow.reset()
+
         self.session.close_all()
+        self.session.expunge_all()
         self.drop_tables()
         self.engine.dispose()
         self.connection.close()
